Module: RubyEvents

Defined in:
lib/ruby_events.rb

Overview

The RubyEvents module contains the core logic used by the events firing class. All Object’s are extended by default with an events accessor that is set to an instance of the RubyEvents::Events class. By calling the methods on this accessor, you can set up and listen to events or callbacks as fired by this class.

Defined Under Namespace

Classes: Events